<?php
namespace MetForm\Core\Forms;
defined( 'ABSPATH' ) || exit;

Class Action{

    use \MetForm\Traits\Singleton;

    private $key_form_settings;
    private $post_type;

    private $fields;
    private $form_id;
    private $form_setting;
    private $title;
    private $response = [];

    public function __construct(){
        if( !current_user_can( 'manage_options' ) ){
            return;
        }
        
        $this->key_form_settings = Base::instance()->form->get_key_form_settings();
        $this->post_type = Base::instance()->form->get_name();

        $this->response = [
            'saved' => false,
            'status' => esc_html("Something went wrong.", 'metform'),
            'data' => [
                ]
            ];
    }

    public function store( $form_id, $form_setting ){

        $this->fields = $this->get_fields();
        $this->sanitize( $form_setting );
        $this->form_id = $form_id;
        
        if(isset($form_setting['mf_zapier']) && $form_setting['mf_zapier'] == '1' && $form_setting['mf_zapier'] != ''){
            
            $map_data = \MetForm\Core\Entries\Action::instance()->get_fields($form_id);
            $email_name = \MetForm\Core\Entries\Action::instance()->get_email_name($map_data);

            $existing_settings = \MetForm\Core\Entries\Action::instance()->get_form_settings($this->form_id);
            $zapier = new \MetForm\Core\Integrations\Zapier();

            $url = $form_setting['mf_zapier_webhook'];

            if(!empty($existing_settings) && ($existing_settings['mf_zapier_webhook'] != $form_setting['mf_zapier_webhook'])){
                $this->response['data']['zapier'] = $zapier->call_webhook($form_data[] = null, ['url' => $url, 'email_name' => $email_name]);
            }elseif(empty($existing_settings)){
                $this->response['data']['zapier'] = $zapier->call_webhook($form_data[] = null, ['url' => $url, 'email_name' => $email_name]);
            }
            
        }

        if($this->form_id == 0){
            $this->insert();
        }else{
            $this->update();
        }

        return $this->response;
        
    }
                
    public function insert(){

        $this->title = ($this->form_setting['form_title'] != '') ? $this->form_setting['form_title'] : 'New Form # '.time();

        $defaults = array(
            'post_title' => $this->title,
            'post_status' => 'publish',
            'post_type' => $this->post_type,
        );
        $this->form_id = wp_insert_post( $defaults );

        update_post_meta( $this->form_id, $this->key_form_settings, $this->form_setting );
        update_post_meta( $this->form_id, '_wp_page_template', 'elementor_canvas' );

        $this->response['saved'] = true;
        $this->response['status'] = esc_html('Form settings inserted','metform');

        if((!array_key_exists('store_entries',$this->form_setting)) && (!array_key_exists('enable_user_notification',$this->form_setting)) && (!array_key_exists('enable_admin_notification',$this->form_setting)) && (!array_key_exists('mf_mail_chimp',$this->form_setting)) && (!array_key_exists('mf_zapier',$this->form_setting))){
            $this->response['saved'] = false;
            $this->response['status'] = esc_html('You must active at least one field of these fields "store entry/ Confirmation/ Notification/ MailChimp/ Zapier". ','metform'); 
        }
                
        $this->response['data']['id'] = $this->form_id;
        $this->response['data']['title'] = $this->title;
        $this->response['data']['type'] = $this->post_type;

    }

    public function update(){

        $this->title = ($this->form_setting['form_title'] != '') ? $this->form_setting['form_title'] : 'New Form # '.time();

        if( isset( $this->form_setting['form_title'] ) ){
            $update_post = array(
                'ID'           => $this->form_id,
                'post_title'   => $this->title,
            );
            wp_update_post( $update_post );
        }

        update_post_meta( $this->form_id, $this->key_form_settings, $this->form_setting );
        update_post_meta( $this->form_id, '_wp_page_template', 'elementor_canvas' );

        $this->response['saved'] = true;
        $this->response['status'] = esc_html('Form settings updated','metform');

        if((!array_key_exists('store_entries',$this->form_setting)) && (!array_key_exists('enable_user_notification',$this->form_setting)) && (!array_key_exists('enable_admin_notification',$this->form_setting)) && (!array_key_exists('mf_mail_chimp',$this->form_setting)) && (!array_key_exists('mf_zapier',$this->form_setting))){
            $this->response['saved'] = false;
            $this->response['status'] = esc_html('You must active at least one field of these fields "store entry/ Confirmation/ Notification/ MailChimp/ Zapier". ','metform'); 
        }

        $this->response['data']['id'] = $this->form_id;
        $this->response['data']['title'] = $this->title;
        $this->response['data']['type'] = $this->post_type;
    
    }
            
    public function get_fields(){
        return Base::instance()->form->get_form_settings_fields();
    }

    public function sanitize( $form_setting, $fields = null ){
        if( $fields == null ){
            $fields = $this->fields;
        }
        foreach( $form_setting as $key => $value ){

            if( isset( $fields[$key] ) ){
                $this->form_setting[ $key ] = $value;
            }

        }
    }


    public function get_all_data( $post_id ){

        $post = get_post( $post_id );

        $data = get_post_meta( $post->ID, $this->key_form_settings,  true );

        $data['form_title'] = get_the_title($post_id);

        return $data;   

    }
}