(function ($, elementor) {
	"use strict";

	var scope;
	
	function triggerRepeater($scope){
		var el = $scope.find('.mf-input-wrapper .mf-repater-range-input[type="range"]');
		var min = el.attr('min');
		var max = el.attr('max');
		var step = el.attr('step');

		var config = {
			step: step,
			min: min,
			max: max,
		}
		el.asRange(config);
	}

	var MetForm = {

		init: function () {
			var widgets = {
				'mf-range.default': MetForm.RangeInput,
				'mf-date.default': MetForm.DateInput,
				'mf-time.default': MetForm.TimeInput,
				'mf-select.default': MetForm.SelectInput,
				'mf-multi-select.default': MetForm.MultiSelectInput,
				'mf-rating.default': MetForm.Rating,
				'mf-mobile.default': MetForm.Mobile,
				'mf-image-select.default': MetForm.ImageSelect,
				'mf-toggle-select.default': MetForm.ToggleSelect,
				'mf-simple-repeater.default': MetForm.SimpleRepeater,

			};
			$.each(widgets, function (widget, callback) {
				elementor.hooks.addAction('frontend/element_ready/' + widget, callback);
			});
		},

		RangeInput: function ($scope) {
			var el = $scope.find('.mf-rs-range');
			var min = el.attr('min');
			var max = el.attr('max');
			var step = el.attr('step');
			var range = el.attr('range');

			var config = {
				step: step,
				min: min,
				max: max,
			}

			if (range == 'true') config.range = Boolean(range);

			el.asRange(config);

			el.on('asRange::change', function (e) {
				var val = $(this).asRange('get');

				if(Array.isArray(val)){
					val = Number(val[1]) - Number(val[0]);
				}
				$(this).val(val).trigger('change');
			});
		},

		SimpleRepeater: function ($scope) {
			scope = $scope;
			    /* Create Repeater */
				$scope.find(".mf-input-repeater").createRepeater({
					showFirstItemToDefault: true,
				});
			triggerRepeater($scope);
		},

		DateInput: function ($scope) {
			var el = $scope.find('.mf-date-input');
			var minDateToday = el.data('mfmindatetoday');
			var rangeDate = el.data('mfrangedate');
			var dateFormat = el.data('mf_date_format');
			var dateToday = el.data('mfdefaultdate');
			var wrapper = $scope.find('.mf-input-wrapper');

			var config = {
				appendTo: wrapper.get(0),
				dateFormat: dateFormat,
			}

			if (dateToday == 'today') config.defaultDate = 'today';
			if (minDateToday == 'yes') config.minDate = 'today';
			if (rangeDate == 'yes') config.mode = 'range';
			el.flatpickr(config);
		},

		TimeInput: function ($scope) {
			var el = $scope.find('.mf-input-time');
			var time24h = el.attr('mftime24h');
			var wrapper = $scope.find('.mf-input-wrapper');
			var config = {
				appendTo: wrapper.get(0),
				dateFormat: "h:i K",
				enableTime: true,
				noCalendar: true
			}

			if (time24h == 'yes') {
				config.dateFormat = 'H:i';
				config.time_24hr = true;
			}

			el.flatpickr(config);
		},

		SelectInput: function ($scope) {
			var el = $scope.find('select.mf-input-dropdown');

			el.select2({
				dropdownParent: $scope.find('.mf-input-wrapper')
			});
		},

		MultiSelectInput: function ($scope) {
			var el = $scope.find('select.mf-input-multiselect');
			el.select2({
				dropdownParent: $scope.find('.mf-input-wrapper')
			});
		},

		Rating: function ($scope) {
			var el = $scope.find('.mf-input-rating li');
			el.on('mouseover', function () {
				var onStar = parseInt($(this).data('value'), 10); // The star currently mouse on
				$(this).parent().children('li.star-li').each(function (e) {
					if (e < onStar) {
						$(this).addClass('hover');
					}
					else {
						$(this).removeClass('hover');
					}
				});

			}).on('mouseout', function () {
				$(this).parent().children('li.star-li').each(function (e) {
					$(this).removeClass('hover');
				});
			});


			el.on('click', function () {
				var onStar = parseInt($(this).data('value'), 10);
				var stars = $(this).parent().children('li.star-li');

				for (let i = 0; i < stars.length; i++) {
					$(stars[i]).removeClass('selected');
				}

				for (let i = 0; i < onStar; i++) {
					$(stars[i]).addClass('selected');
				}

				var displayId = $(this).parents().find('input.mf-input-hidden');
				displayId.val(onStar);

				var msg = "";
				if (onStar > 1) {
					msg = "<strong>" + onStar + "</strong>";
				}
				else {
					msg = "<strong>" + onStar + " </strong>";
				}

			});
		},

		Mobile: function ($scope) {
			var href = mf_plugin.mf_dir;
			var mfInputTel = $scope.find('.mf-input[type="tel"]');

			var el = mfInputTel;

			var intl = window.intlTelInput(el[0], {
				nationalMode: true,
				separateDialCode: true,
				utilsScript: href + "libs/assets/js/utils.js?1562189064761",
			});

		},
		// it's already trigger change function, so this is not necessary
		// ImageSelect: function($scope){
		// 	var el = $scope.find('.mf-input-wrapper .mf-image-select-input[type="radio"]');

		// 	el.on('click', function (e) {
		// 		el.trigger('change');
		// 	});
		// },

		// it's already trigger change function, so this is not necessary
		// ToggleSelect: function($scope){
		// 	var el = $scope.find('.mf-input-wrapper .mf-toggle-select-input[type="radio"]');

		// 	el.on('click', function (e) {
		// 		el.trigger('change');
		// 	});
		// },
	};

	$(window).on('elementor/frontend/init', MetForm.init);

	$('.repeater-add-btn').on('click', function(){
		setTimeout( function() {
			triggerRepeater(scope);
			}, 1000);
		// triggerRepeater(scope);
	});

}(jQuery, window.elementorFrontend));