<?php
namespace Elementor;
defined( 'ABSPATH' ) || exit;

Class MetForm_Input_File_Upload extends Widget_base{

	use \MetForm\Traits\Common_Controls;
	use \MetForm\Traits\Conditional_Controls;

    public function get_name() {
		return 'mf-file-upload';
    }
    
	public function get_title() {
		return esc_html__( 'File Upload', 'metform' );
    }

    public function show_in_panel() {
        return 'metform-form' == get_post_type();
    }
    
    public function get_categories() {
		return [ 'metform' ];
	}

		
	public function get_keywords() {
        return ['metform', 'input', 'file', 'upload'];
    }

    protected function _register_controls() {
        
        $this->start_controls_section(
			'content_section',
			[
				'label' => esc_html__( 'Content', 'metform' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

        $this->input_content_controls(['NO_PLACEHOLDER']);

        $this->end_controls_section();

        $this->start_controls_section(
			'settings_section',
			[
				'label' => esc_html__( 'Settings', 'metform' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

        $this->input_setting_controls();
        
        $this->add_control( 
            'mf_input_file_size_status', 
            [
                'label'        => esc_html__( 'File Size Limit : ', 'metform' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_off'    => 'Off',
                'label_on'     => 'On',
                'return_value' => 'on',
            ] 
        );

       $this->add_control(
            'mf_input_file_size_limit',
            [
                'label' => esc_html__( 'Maximum File Size (KB) : ', 'metform' ),
                'type' => Controls_Manager::NUMBER,
                'default' => esc_html__( '128', 'metform' ),
                'condition'    => [
                    'mf_input_file_size_status' => 'on',
                ],
            ]
        );

        $this->add_control(
			'mf_input_file_types',
			[
				'label' => esc_html__( 'File Types : ', 'metform' ),
				'type' => Controls_Manager::SELECT2,
				'multiple' => true,
				'options' => [
					'.jpg'  => esc_html__( '.jpg', 'metform' ),
					'.jpeg'  => esc_html__( '.jpeg', 'metform' ),
					'.gif'  => esc_html__( '.gif', 'metform' ),
					'.png'  => esc_html__( '.png', 'metform' ),
					'.ico'  => esc_html__( '.ico', 'metform' ),
					'.pdf'  => esc_html__( '.pdf', 'metform' ),
					'.doc'  => esc_html__( '.doc', 'metform' ),
					'.docx'  => esc_html__( '.docx', 'metform' ),
					'.ppt'  => esc_html__( '.ppt', 'metform' ),
					'.pptx'  => esc_html__( '.pptx', 'metform' ),
					'.pps'  => esc_html__( '.pps', 'metform' ),
					'.ppsx'  => esc_html__( '.ppsx', 'metform' ),
					'.odt'  => esc_html__( '.odt', 'metform' ),
					'.xls'  => esc_html__( '.xls', 'metform' ),
					'.xlsx'  => esc_html__( '.xlsx', 'metform' ),
					'.psd'  => esc_html__( '.psd', 'metform' ),
					'.mp3'  => esc_html__( '.mp3', 'metform' ),
					'.m4a'  => esc_html__( '.m4a', 'metform' ),
					'.ogg'  => esc_html__( '.ogg', 'metform' ),
					'.wav'  => esc_html__( '.wav', 'metform' ),
					'.mp4'  => esc_html__( '.mp4', 'metform' ),
					'.m4v'  => esc_html__( '.m4v', 'metform' ),
					'.mov'  => esc_html__( '.mov', 'metform' ),
					'.wmv'  => esc_html__( '.wmv', 'metform' ),
					'.avi'  => esc_html__( '.avi', 'metform' ),
					'.mpg'  => esc_html__( '.mpg', 'metform' ),
					'.ogv'  => esc_html__( '.ogv', 'metform' ),
					'.3gp'  => esc_html__( '.3gp', 'metform' ),
					'.3g2'  => esc_html__( '.3g2', 'metform' ),
					'.zip'  => esc_html__( '.zip', 'metform' ),
					'.csv'  => esc_html__( '.csv', 'metform' ),
				],
                'default' => [ '.jpg', '.jpeg', '.gif', '.png' ],
			]
		);

		$this->end_controls_section();
		
		if(class_exists('\MetForm\Base\Package')){
			$this->input_conditional_control();
		}

        $this->start_controls_section(
			'label_section',
			[
				'label' => esc_html__( 'Label', 'metform' ),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition'    => [
                    'mf_input_label_status' => 'yes',
                ],
			]
        );

		$this->input_label_controls();

        $this->end_controls_section();

        $this->start_controls_section(
			'input_section',
			[
				'label' => esc_html__( 'Input', 'metform' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
        );

        $this->input_controls();

        $this->end_controls_section();

        $this->start_controls_section(
			'help_text_section',
			[
				'label' => esc_html__( 'Help Text', 'metform' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'mf_input_help_text!' => ''
				]
			]
		);
		
		$this->input_help_text_controls();

        $this->end_controls_section();

        
	}

    protected function render($instance = []){
		$settings = $this->get_settings_for_display();
        extract($settings);

        $accept = (is_array($mf_input_file_types)) ? implode(', ', $mf_input_file_types) : '.jpg, .jpeg, .gif, .ico';

		$class = (isset($settings['mf_conditional_logic_form_list']) ? 'mf-conditional-input' : '');

		echo "<div class='mf-input-wrapper ".$class."' data-mf-form-conditional-logic-requirement='".(isset($mf_conditional_logic_form_and_or_operators) ? $mf_conditional_logic_form_and_or_operators : '')."'>";
		
		if($mf_input_label_status == 'yes'){
			?>
            <label class="mf-input-label" for="mf-input-file-upload-<?php echo esc_attr($this->get_id()); ?>"><?php echo esc_html($mf_input_label); ?>
                <span class="mf-input-required-indicator"><?php echo esc_html(($mf_input_required === 'yes') ? '*' : '');?></span>
            </label>
			<?php
		}
        ?>
		<input type="file" class="mf-input" id="mf-input-file-upload-<?php echo esc_attr($this->get_id()); ?>" 
            name="<?php echo esc_attr($mf_input_name); ?>" 
            <?php echo esc_attr(($mf_input_required === 'yes') ? 'required' : '')?>
            accept="<?php echo esc_attr($accept != null ? $accept : '');?>"
			<?php //echo esc_attr($mf_input_readonly_status); ?>
		>
		<?php
		if($mf_input_help_text != ''){
			echo "<span class='mf-input-help'>".esc_html($mf_input_help_text)."</span>";
		}
		echo "</div>";
    }

}